@@ -132,7 +132,7 @@ ExecStart={_path} -c {config_path}
 WantedBy=multi-user.target
     """.format(username=username, _path=_path, config_path=config_path)
     # return template
-    with open('/etc/systemd/system/rpi2mqtt.service', 'w') as f:
+    with open('~/.config/systemd/user/rpi2mqtt.service', 'w') as f:
         f.write(template)
 
 if __name__ == '__main__':
