@@ -99,10 +99,10 @@ class HestiaPi(Sensor):
             GPIO.setup(pin, GPIO.IN)
 
         # Subscribe to MQTT command topics
-        mqtt.subscribe(self.mode_command_topic, self.mqtt_set_mode_callback)
-        mqtt.subscribe(self.temperature_set_point_command_topic, self.mqtt_set_temperature_set_point_callback)
-        mqtt.subscribe(self.fan_command_topic, self.mqtt_set_fan_state_callback)
-        mqtt.subscribe(self.aux_command_topic, self.mqtt_set_aux_mode_callback)
+        MQTT.subscribe(self.mode_command_topic, self.mqtt_set_mode_callback)
+        MQTT.subscribe(self.temperature_set_point_command_topic, self.mqtt_set_temperature_set_point_callback)
+        MQTT.subscribe(self.fan_command_topic, self.mqtt_set_fan_state_callback)
+        MQTT.subscribe(self.aux_command_topic, self.mqtt_set_aux_mode_callback)
 
     @property
     def mode_command_topic(self):
@@ -343,7 +343,7 @@ class HestiaPi(Sensor):
                 self.on()
             # system is inactive, should we turn it on?
         # logging.info('HVAC is {}. Mode is {}. Temperature is {}.'.format(self.active, self.mode, self.temperature))
-        mqtt.publish(self.topic, self.payload())
+        MQTT.publish(self.topic, self.payload())
 
     # def mode_is_changeable(self):
     #     """Can thermostat active mode be chagned?"""
@@ -437,10 +437,10 @@ class HestiaPi(Sensor):
     
     def mqtt_ping(self, topic, callback):
         logging.debug("Checing subcription status on topic {}".format(topic))
-        response = mqtt.publish(topic, "ping")
+        response = MQTT.publish(topic, "ping")
         if response != 'pong':
             logging.warn("Not subscribed to topic {}. Resubscribing...".format(topic))
-            mqtt.subscribe(topic, callback)
+            MQTT.subscribe(topic, callback)
 
     """
     MQTT subscription callbacks
